//	Buggalo a simple audio keyer for hamradio rigs that lacks CW mode.
//	Copyright (C) 2009  SM0KBW / Bengt Andersson
//
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.


#ifndef	EEPROM_CONST
#define 	EEPROM_CONST

#define CH_STORE			0
#define PITCH_CONST		0xB8
#define DOT_CONST			0x88
#define DOT_CONST_LO		0xF0
#define DOT_CONST_HI		0x20


// memory position
// 12F683 has 256 bytes eprom and 12F675 only has 128

#if defined(_12F683)
#define SPC_STORE		0xE0
#define CH_STORE_SZ 	SPC_STORE 
#define PITCH_NUM 		0xFC
#define DOT_LEN_LO		0xFD
#define DOT_LEN_HI		0xFE
#define DOT_LEN		0xFF
#else
#define SPC_STORE		0x70
#define CH_STORE_SZ 	SPC_STORE 
#define PITCH_NUM 		0x7C
#define DOT_LEN_LO		0x7D
#define DOT_LEN_HI		0x7E
#define DOT_LEN		0x7F
#endif

// The high five bits in a byte describes the token the lower three
// containes the length.
// Q is  - - . - and stores as 1101 0100 -> 0xD4
#define CW_A		0x42
#define CW_B		0x84 
#define CW_C		0xA4
#define CW_D		0x83
#define CW_E		0x01
#define CW_F		0x24
#define CW_G		0xC3
#define CW_H		0x04
#define CW_I		0x02
#define CW_J		0x74
#define CW_K		0xA3
#define CW_L		0x44
#define CW_M		0xC2
#define CW_N		0x82
#define CW_O		0xE3
#define CW_P		0x64
#define CW_Q		0xD4 
#define CW_R		0x43
#define CW_S		0x03
#define CW_T		0x81
#define CW_U		0x23
#define CW_V		0x14
#define CW_W		0x63
#define CW_X		0x94
#define CW_Y		0xB4
#define CW_Z		0xC4
#define CW_LNK		0x06
#define CW_MSK		0x07
#define CW_END		0x00

// CW_LNK marks that the token continues i the next stored byte

#define CW_0		0xFD
#define CW_1		0x7D
#define CW_2		0x3D
#define CW_3		0x1D
#define CW_4		0x0D
#define CW_5		0x05
#define CW_6		0x85
#define CW_7		0xC5
#define CW_8		0xE5
#define CW_9		0xF5


// Pre program the eeprom with a message string

__EEPROM_DATA (CW_B, CW_U, CW_G, CW_G, CW_A, CW_L, CW_O, CW_D);
__EEPROM_DATA (CW_E, CW_S, CW_M, CW_0, CW_K, CW_B, CW_W, CW_7);
__EEPROM_DATA (CW_3, CW_G, CW_O, CW_O, CW_D, CW_L, CW_U, CW_C);
__EEPROM_DATA (CW_K, CW_END, 0, 0, 0, 0, 0, 0); 
__EEPROM_DATA (0, 0, 0, 0, 0, 0, 0, 0); 
__EEPROM_DATA (0, 0, 0, 0, 0, 0, 0, 0); 
__EEPROM_DATA (0, 0, 0, 0, 0, 0, 0, 0); 
__EEPROM_DATA (0, 0, 0, 0, 0, 0, 0, 0); 

__EEPROM_DATA (0, 0, 0, 0, 0, 0, 0, 0); 
__EEPROM_DATA (0, 0, 0, 0, 0, 0, 0, 0); 
__EEPROM_DATA (0, 0, 0, 0, 0, 0, 0, 0); 
__EEPROM_DATA (0, 0, 0, 0, 0, 0, 0, 0); 
__EEPROM_DATA (0, 0, 0, 0, 0, 0, 0, 0); 
__EEPROM_DATA (0, 0, 0, 0, 0, 0, 0, 0); 
__EEPROM_DATA (0x00, 0x80, 0x88, 0x00, 0, 0, 0, 0); 
__EEPROM_DATA (0, 0, 0, 0, PITCH_CONST, DOT_CONST_LO, DOT_CONST_HI, DOT_CONST); 

#if defined(_12F683)
__EEPROM_DATA (0, 0, 0, 0, 0, 0, 0, 0); 
__EEPROM_DATA (0, 0, 0, 0, 0, 0, 0, 0); 
__EEPROM_DATA (0, 0, 0, 0, 0, 0, 0, 0); 
__EEPROM_DATA (0, 0, 0, 0, 0, 0, 0, 0); 
__EEPROM_DATA (0, 0, 0, 0, 0, 0, 0, 0); 
__EEPROM_DATA (0, 0, 0, 0, 0, 0, 0, 0); 
__EEPROM_DATA (0, 0, 0, 0, 0, 0, 0, 0); 
__EEPROM_DATA (0, 0, 0, 0, 0, 0, 0, 0); 

__EEPROM_DATA (0, 0, 0, 0, 0, 0, 0, 0); 
__EEPROM_DATA (0, 0, 0, 0, 0, 0, 0, 0); 
__EEPROM_DATA (0, 0, 0, 0, 0, 0, 0, 0); 
__EEPROM_DATA (0, 0, 0, 0, 0, 0, 0, 0); 
__EEPROM_DATA (0x02, 0x80, 0x88, 0x00, 0, 0, 0, 0); 
__EEPROM_DATA (0, 0, 0, 0, 0, 0, 0, 0); 
__EEPROM_DATA (0, 0, 0, 0, 0, 0, 0, 0); 
__EEPROM_DATA (0, 0, 0, 0, PITCH_CONST, DOT_CONST_LO, DOT_CONST_HI, DOT_CONST); 
#endif


#endif //	EEPROM_CONST
